==> location-input-component-0.0.15.tgz: package/src/locationInput.tsx <==
import {
  Box,
  Icon,
  IconButton,
  Input,
  InputGroup,
  InputRightElement,
  Spinner,
  Text,
} from "@chakra-ui/react";
import { defineComponent } from "@qorebase/app-component";
import React from "react";
import { TargetLock } from "@feedloop/icon";

const TextInput = defineComponent({
  name: "Location Input",
  type: "none",
  icon: "LocationInput",
  group: "input",
  display: "inline",
  defaultProps: {
    label: "Location Input",
    hidden: false,
    placeholder: "Placeholder here",
    data: {
      inputID: "location",
      field: { type: "string", options: { format: "text" } },
      validation: {
        required: false,
      },
    },
    defaultValue: "",
  },
  propDefinition: {
    label: { group: "Design", type: "expression", options: {} },
    placeholder: {
      group: "Design",
      type: "expression",
      options: {},
    },
    hidden: { group: "Design", type: "boolean", options: {} },
    data: {
      group: "Design",
      type: "state",
      options: {
        inputID: "location",
        field: { type: "string", options: { format: "text" } },
      },
    },
    defaultValue: {
      group: "Design",
      type: "expression",
      options: {},
    },
  },
  Component: (props) => {
    const title = props.hooks.useEvaluate(props.properties.label);
    const placeholder = props.hooks.useEvaluate(props.properties.placeholder);
    const defaultValue = props.hooks.useEvaluate(props.properties.defaultValue);
    const data = props.hooks.useRuntimeInput<"string">(
      props.properties.data,
      props.data.page.row,
      {
        defaultValue,
        validate: (value) => {
          if (!value) {
            return { error: "Required field, Please enter the data" };
          }
        },
      }
    );
    const handleChange = React.useCallback(
      (e: React.ChangeEvent<HTMLInputElement>) => {
        data.onChange(e.currentTarget.value);
      },
      [data.onChange]
    );
    const [supported, setSupported] = React.useState(true);
    const [locating, setLocating] = React.useState(true);

    const getLocation = () => {
      if (navigator.geolocation) {
        setLocating(true);
        navigator.geolocation.getCurrentPosition((position) => {
          data.onChange(
            `${position.coords.latitude},${position.coords.longitude}`
          );
          setLocating(false);
        });
      } else {
        setLocating(false);
        setSupported(false);
      }
    };

    React.useEffect(() => {
      getLocation();
    }, []);

    return (
      <Box display={props.properties.hidden ? "none" : undefined}>
        <Text fontSize="lg" pb={2} data-test="location-input-title">
          {title}
        </Text>
        <InputGroup size="md">
          <Input
            pr="10"
            style={{ border: "1px solid rgb(226, 232, 240)" }}
            bgColor={"surface.900"}
            placeholder={placeholder}
            key={props.properties.data.inputID}
            name={props.properties.data.inputID}
            defaultValue={data.value}
            onChange={handleChange}
            disabled={supported}
            _disabled={{ border: "1px solid rgb(226, 232, 240)" }}
            data-test="location-input"
          />
          <InputRightElement width="10">
            {locating ? (
              <Spinner />
            ) : (
              <IconButton
                aria-label="locate"
                variant="link"
                icon={<Icon as={TargetLock} />}
                onClick={getLocation}
                data-test="location-input-toggle"
              />
            )}
          </InputRightElement>
        </InputGroup>
        {!!data.validation.error && (
          <Text fontSize="sm" color="red" data-test="location-input-error">
            {data.validation.error}
          </Text>
        )}
      </Box>
    );
  },
});

export default TextInput;

==> location-input-component-0.0.25.tgz: package/src/locationInput.tsx <==
import {
  Box,
  Icon,
  IconButton,
  Input,
  InputGroup,
  InputRightElement,
  Spinner,
  Text,
} from "@chakra-ui/react";
import { defineComponent, useDisableCondition } from "@qorebase/app-component";
import React from "react";
import { TargetLock } from "@feedloop/icon";
import InputComponentLabel from "@qorebase/app-runtime/src/components/InputComponentLabel";

const TextInput = defineComponent({
  name: "Location Input",
  type: "none",
  icon: "LocationInput",
  group: "input",
  display: "inline",
  defaultProps: {
    label: "Location Input",
    hidden: false,
    placeholder: "Placeholder here",
    data: {
      inputID: "location",
      field: { type: "string", options: { format: "text" } },
      validation: {
        required: false,
      },
    },
    defaultValue: "",
  },
  propDefinition: {
    label: { group: "Design", type: "expression", options: {} },
    placeholder: {
      group: "Design",
      type: "expression",
      options: {},
    },
    hidden: { group: "Design", type: "boolean", options: {} },
    data: {
      group: "Design",
      type: "state",
      options: {
        inputID: "location",
        field: { type: "string", options: { format: "text" } },
      },
    },
    defaultValue: {
      group: "Design",
      type: "expression",
      options: {},
    },
  },
  Component: (props) => {
    const title = props.hooks.useEvaluate(props.properties.label);
    const placeholder = props.hooks.useEvaluate(props.properties.placeholder);
    const propsDefaultValue = props.hooks.useEvaluate(
      props.properties.defaultValue
    );
    const defaultValue = React.useMemo(
      () => (!propsDefaultValue ? undefined : propsDefaultValue),
      [propsDefaultValue]
    );
    const data = props.hooks.useRuntimeInput<"string">(
      props.properties.data,
      props.data.page.row,
      {
        defaultValue,
        validate: (value) => {
          if (typeof value === "undefined") {
            return { error: "" };
          } else if (!value) {
            return { error: "Required field, Please enter the data" };
          }
        },
      }
    );
    const handleChange = React.useCallback(
      (e: React.ChangeEvent<HTMLInputElement>) => {
        data.onChange(e.currentTarget.value);
      },
      [data.onChange]
    );
    const [supported, setSupported] = React.useState(true);
    const [locating, setLocating] = React.useState(true);

    const getLocation = () => {
      if (navigator.geolocation) {
        setLocating(true);
        navigator.geolocation.getCurrentPosition((position) => {
          data.onChange(
            `${position.coords.latitude},${position.coords.longitude}`
          );
          setLocating(false);
        });
      } else {
        setLocating(false);
        setSupported(false);
      }
    };

    // @ts-ignore
    const { isDisabled } = useDisableCondition(props.instance);
    const disabledProperties: React.CSSProperties = {
      border: "1px solid rgb(226, 232, 240)",
      pointerEvents: isDisabled ? "none" : "auto",
      background: isDisabled && "#E7E7E7",
      color: isDisabled && "#A2A2A2",
    };

    React.useEffect(() => {
      getLocation();
    }, []);

    return (
      <Box display={props.properties.hidden ? "none" : undefined}>
        <InputComponentLabel
          title={title}
          name="location"
          isRequired={props.properties.data.validation?.required}
          isEmpty={title.length === 0}
        />
        <InputGroup size="md">
          <Input
            pr="10"
            style={disabledProperties}
            bgColor={"surface.900"}
            placeholder={placeholder}
            key={props.properties.data.inputID}
            name={props.properties.data.inputID}
            defaultValue={data.value}
            onChange={handleChange}
            disabled={supported}
            _disabled={{ border: "1px solid rgb(226, 232, 240)" }}
            data-test="location-input"
          />
          <InputRightElement width="10">
            {locating ? (
              <Spinner />
            ) : (
              <IconButton
                aria-label="locate"
                variant="link"
                icon={<Icon as={TargetLock} />}
                onClick={getLocation}
                data-test="location-input-toggle"
                style={disabledProperties}
              />
            )}
          </InputRightElement>
        </InputGroup>
        {!!data.validation.error && (
          <Text fontSize="sm" color="red" data-test="location-input-error">
            {data.validation.error}
          </Text>
        )}
      </Box>
    );
  },
});

export default TextInput;
